import { useState } from 'react';
import { Keyboard } from 'react-native';
import { useLoad, useUnload } from 'react-native-lifecycle';
const emptyCoordinates = Object.freeze({
    screenX: 0,
    screenY: 0,
    width: 0,
    height: 0,
});
const initialValue = {
    start: emptyCoordinates,
    end: emptyCoordinates,
};
export default () => {
    const [shown, setShown] = useState(false);
    const [coordinates, setCoordinates] = useState(initialValue);
    const [keyboardHeight, setKeyboardHeight] = useState(0);
    const onKeyboardWillShow = e => {
        setCoordinates({ start: e.startCoordinates, end: e.endCoordinates });
    };
    const onKeyboardDidShow = e => {
        setShown(true);
        setCoordinates({ start: e.startCoordinates, end: e.endCoordinates });
        setKeyboardHeight(e.endCoordinates.height);
    };
    const onKeyboardWillHide = e => {
        setCoordinates({ start: e.startCoordinates, end: e.endCoordinates });
    };
    const onKeyboardDidHide = e => {
        setShown(false);
        if (e) {
            setCoordinates({ start: e.startCoordinates, end: e.endCoordinates });
        }
        else {
            setCoordinates(initialValue);
            setKeyboardHeight(0);
        }
    };
    const dismiss = () => {
        Keyboard.dismiss();
    };
    useLoad(() => {
        Keyboard.addListener('keyboardWillShow', onKeyboardWillShow);
        Keyboard.addListener('keyboardDidShow', onKeyboardDidShow);
        Keyboard.addListener('keyboardWillHide', onKeyboardWillHide);
        Keyboard.addListener('keyboardDidHide', onKeyboardDidHide);
    });
    useUnload(() => {
        Keyboard.removeListener('keyboardWillShow', onKeyboardWillShow);
        Keyboard.removeListener('keyboardDidShow', onKeyboardDidShow);
        Keyboard.removeListener('keyboardWillHide', onKeyboardWillHide);
        Keyboard.removeListener('keyboardDidHide', onKeyboardDidHide);
    });
    return {
        keyboardShown: shown,
        coordinates,
        keyboardHeight,
        dismiss,
    };
};
